package org.opengroup.osdu.notification.subscriptions;

import static org.junit.Assert.assertEquals;

import org.apache.http.HttpStatus;

import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import com.sun.jersey.api.client.ClientResponse;
import org.opengroup.osdu.notification.util.TestUtils;

import java.util.UUID;

public class LegalTagUtils {

    public static ClientResponse create(String legalTagName, String token, boolean isTestPartition) throws Exception {
        return create("US", legalTagName, "2099-01-25", "Public Domain Data", token, isTestPartition);
    }

    protected static ClientResponse create(String countryOfOrigin, String name, String expDate, String dataType, String token, boolean isTestPartition)
            throws Exception {
        String body = getBody(countryOfOrigin, name, expDate, dataType);
        ClientResponse response = StorageTestUtils.send(getLegalUrl(), "legaltags", "POST", StorageTestUtils.getHeaders(TenantUtils.getTenantName(isTestPartition), token, UUID.randomUUID().toString(), isTestPartition), body,
                "");

        assertEquals(HttpStatus.SC_CREATED, response.getStatus());
        Thread.sleep(100);
        return response;
    }

    public static ClientResponse delete(String legalTagName, String token, boolean isTestPartition) throws Exception {
        return StorageTestUtils.send(getLegalUrl(), "legaltags/" + legalTagName, "DELETE", StorageTestUtils.getHeaders(TenantUtils.getTenantName(isTestPartition), token, UUID.randomUUID().toString(), isTestPartition), "", "");
    }

    protected static String getLegalUrl() {
        String legalUrl = System.getProperty("LEGAL_URL", System.getenv("LEGAL_URL"));
        return legalUrl;
    }

    protected static String getBody(String countryOfOrigin, String name, String expDate, String dataType) {

        JsonArray coo = new JsonArray();
        coo.add(countryOfOrigin);

        JsonObject properties = new JsonObject();
        properties.add("countryOfOrigin", coo);
        properties.addProperty("contractId", "A1234");
        properties.addProperty("expirationDate", expDate);
        properties.addProperty("dataType", dataType);
        properties.addProperty("originator", "MyCompany");
        properties.addProperty("securityClassification", "Public");
        properties.addProperty("exportClassification", "EAR99");
        properties.addProperty("personalData", "No Personal Data");

        JsonObject tag = new JsonObject();
        tag.addProperty("name", name);
        tag.addProperty("description", "test for " + name);
        tag.add("properties", properties);

        return tag.toString();
    }
}
