/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.notification.api;

import org.junit.Ignore;
import com.sun.jersey.api.client.ClientResponse;
import org.junit.Test;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.notification.util.BaseTestTemplate;
import org.opengroup.osdu.notification.util.Config;
import org.opengroup.osdu.notification.util.RestDescriptor;
import org.opengroup.osdu.notification.util.TestUtils;
import org.opengroup.osdu.core.common.notification.*;
import org.opengroup.osdu.core.common.model.notification.*;

import java.util.HashMap;
import java.util.Map;

import static org.junit.Assert.assertEquals;

/**
 * Integration testing for Notification service
 * For HMAC subscription
 */
public abstract class PubsubEndpointHMACTests extends BaseTestTemplate {

    private String subscriptionId = null;
    private String notificationId = null;
    private ISubscriptionService subscriptionService;

    private static SubscriptionFactory factory;

    public static void classSetup() throws Exception {
        descriptor = new PubsubEndpointHMACDescriptor();

        //Configure Register Service Client Library
        SubscriptionAPIConfig config = SubscriptionAPIConfig.builder().rootUrl(Config.Instance().RegisterServicePath).build();
        factory = new SubscriptionFactory(config);
    }

    @Override
    protected String getArg() {
        return notificationId;
    }

    @Override
    protected String getInvalidArg() {
        return null;
    }

    @Override
    protected void deleteResource() throws Exception {
        subscriptionService.delete(subscriptionId);
    }

    @Override
    protected void createResource() throws Exception {
        createResourceInPartition(TestUtils.getOsduTenant());
    }

    private void createResourceInPartition(String partitionId) throws Exception{
        Map<String, String> headers = new HashMap<>();
        headers.put(DpsHeaders.DATA_PARTITION_ID, partitionId);
        headers.put(DpsHeaders.AUTHORIZATION, testUtils.getOpsToken());
        DpsHeaders dpsHeaders = DpsHeaders.createFromMap(headers);
        subscriptionService = factory.create(dpsHeaders);

        //Create a new subscription to pub/sub
        Subscription subscription = new Subscription();
        subscription.setName("subscription-integration-test-hmac");
        subscription.setDescription("subscription created for hmac integration test");
        subscription.setTopic(Config.Instance().Topic);
        //This seems to be a bug. Dont need to add the string
        //subscription.setPushEndpoint(Config.Instance().HMACPushUrl + "hmac-integration-test");
        subscription.setPushEndpoint(Config.Instance().HMACPushUrl);
        HmacSecret secret = new HmacSecret();
        secret.setValue(Config.Instance().hmacSecretValue);

        subscription.setSecret(secret);
        try {
            Subscription subscriptionCreated = subscriptionService.create(subscription);
            notificationId = subscriptionCreated.getNotificationId();
            subscriptionId = subscriptionCreated.getId();
            Config.Instance().NotificationId = notificationId;
        }catch (SubscriptionException e){
            System.out.println("Subscription exception inner response : " + e.getHttpResponse());
            throw e;
        }
    }

    @Override
    protected int expectedOkResponseCode() {
        return 200;
    }

}
