/*
 Copyright 2020-2023 Google LLC
 Copyright 2020-2023 EPAM Systems, Inc

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
*/

package org.opengroup.osdu.notification.util;

import com.google.common.base.Strings;
import lombok.extern.slf4j.Slf4j;

@Slf4j
public class GCPTestUtils extends TestUtils {

  public GCPTestUtils() {}

  @Override
  public synchronized String getOpsToken() throws Exception {
    if (Strings.isNullOrEmpty(opsToken)) {
      opsToken = getToken("DE_OPS_TESTER");
    }
    return opsToken;
  }

  @Override
  public synchronized String getAdminToken() throws Exception {
    if (Strings.isNullOrEmpty(adminToken)) {
      adminToken = getToken("INTEGRATION_TESTER");
    }
    return adminToken;
  }

  @Override
  public synchronized String getEditorToken() throws Exception {
    if (Strings.isNullOrEmpty(editorToken)) {
      editorToken = getToken("DE_EDITOR_TESTER");
    }
    return editorToken;
  }

  @Override
  public synchronized String getNoAccessToken() throws Exception {
    if (Strings.isNullOrEmpty(noAccessToken)) {
      noAccessToken = getToken("DE_NO_ACCESS_TESTER");
    }
    return noAccessToken;
  }

  private String getToken(String testerEnvVar) throws Exception {
    String serviceAccountValue = System.getProperty(testerEnvVar, System.getenv(testerEnvVar));
    String token = new GoogleServiceAccount(serviceAccountValue).getAuthToken();
    return "Bearer " + token;
  }
}
